@@ -40,5 +40,4 @@ class System(Subsystem):
         except EOFError:
             sys.exit(0)
 
-        command_function = self.commands[result]
-        command_function()
+        self.execute_command(result)
